@@ -1,6 +1,8 @@
 pub mod commit;
+pub mod download;
 pub mod resource;
 pub mod search;
 pub mod single_page_app;
 pub mod tpf;
+pub mod upload;
 pub mod web_sockets;
