@@ -20,10 +20,10 @@ pub async fn single_page(
         .content_type("text/html")
         // This prevents the browser from displaying the JSON response upon re-opening a closed tab
         // https://github.com/joepio/atomic-data-rust/issues/137
-        .header(
+        .insert_header((
             "Cache-Control",
             "no-store, no-cache, must-revalidate, private",
-        )
+        ))
         .body(body);
 
     Ok(resp)
